@@ -287,8 +287,10 @@ def environment_services(env=None):
             "settings": {
                 'hostname': env.str(x.upper() + '_RABBITMQ_HOSTNAME', default=EMPTY_STRING),
                 "port": env.int(x.upper() + '_RABBITMQ_PORT', default=ZERO),
+                "use_ssl":env.bool(x.upper() + '_RABBITMQ_SSL', default=False),
                 'username': env.str(x.upper() + '_RABBITMQ_USERNAME', default=EMPTY_STRING),
                 'password': env.str(x.upper() + '_RABBITMQ_PASSWORD', default=EMPTY_STRING),
+                'tls':env.bool(x.upper() + '_RABBITMQ_TLS', default=False),
                 'cert_path': env.str(x.upper() + '_RABBITMQ_CERT_PATH', default=EMPTY_STRING),
                 'connection_timeout': env.int(x.upper() + '_RABBITMQ_CONNECTION_TIMEOUT', default=15)  # seconds
             }
