@@ -5,7 +5,7 @@ import ssl
 class PostgresHandler(SQLAlchemyHandler):
     def __init__(self, settings):
         """
-        Initializes the ￿PostgresHandler with it's special connection string
+        PostgresHandler init with it's special connection string. Also supports for AWS IAM connection token
         :param settings: settings from `mlapp > config.py` depending on handler type name.
         """
         # add ssl
@@ -19,9 +19,11 @@ class PostgresHandler(SQLAlchemyHandler):
 
         super(PostgresHandler, self).__init__(settings)
 
+        password = self.connections_parameters['password'] if self.token is None else self.token
+
         self.connection_string = 'postgresql+pg8000://{0}:{1}@{2}:{3}/{4}'.format(
             self.connections_parameters['user_id'],
-            self.connections_parameters['password'],
+            password,
             self.connections_parameters['hostname'],
             str(self.connections_parameters['port']),
             self.connections_parameters['database_name'])
