@@ -1,25 +1,25 @@
 cli_aml_help = {
     "setup": \
-'''Usgae:
+'''Usage:
 
 `mlapp aml setup` - setup Azure Machine Learning deployment files in your project.
 ''',
     "publish_pipeline": \
-'''Usgae:
+'''Usage:
 
 `mlapp aml publish-pipeline [PIPELINE_NAME] [COMPUTE_TRAGET]` - set the pipeline name and the correct compute target.
 
 for further options look on the options section below.
 ''',
     "deploy_model": \
-'''Usgae:
+'''Usage:
 
-`mlapp aml deploy-model [ASSET_NAME]` - set your asset name.
+`mlapp aml deploy-model [EXPERIMENT_NAME] [ASSET_NAME]` - set your asset name.
 
 for further options look on the options section below.
 ''',
     "add-mlapp-env": \
-'''Usgae:
+'''Usage:
 
 `mlapp aml create-mlapp-env` - create a new python environment containing the ML App library in AzureML. 
 
